Some DP demos - DPRS
Author: Colin P. Stark
Description: Directed percolation and related models implemented in Rust and wrapped in Python.

Skip to content

# Demos

For now, only directed percolation (DP) in 1d and 2d has been implemented. A series of related models are in development. We are currently working on extending DP to 3d.

## Directed percolation

DP model simulations are demonstrated in the following Jupyter notebooks:

- 1d DP for a small lattice, to visualize \(t\) evolution

- 1d DP for a large lattice and large number of iterations, to validate \(t\)-decay of \(\overline\rho(t)\)

- 2d DP for a large lattice and large number of iterations, to validate \(t\)-decay of \(\overline\rho(t)\)

Related pure-Python demos can be found here:

- Python demos